@@ -67,6 +67,8 @@ impl Serialize for Bson {
             Bson::Null => serializer.serialize_unit(),
             Bson::Int32(v) => serializer.serialize_i32(*v),
             Bson::Int64(v) => serializer.serialize_i64(*v),
+            Bson::UInt32(v) => serializer.serialize_u32(*v),
+            Bson::UInt64(v) => serializer.serialize_u64(*v),
             Bson::ObjectId(oid) => oid.serialize(serializer),
             Bson::DateTime(dt) => dt.serialize(serializer),
             Bson::Binary(b) => b.serialize(serializer),
@@ -219,12 +221,7 @@ impl ser::Serializer for Serializer {
 
     #[inline]
     fn serialize_u64(self, value: u64) -> crate::ser::Result<Bson> {
-        use std::convert::TryFrom;
-
-        match i64::try_from(value) {
-            Ok(ivalue) => Ok(Bson::Int64(ivalue)),
-            Err(_) => Err(Error::UnsignedIntegerExceededRange(value)),
-        }
+        Ok(Bson::UInt64(value))
     }
 
     #[inline]
